﻿#nullable disable

using System.ComponentModel.DataAnnotations;
using System.Reflection;

namespace Samples;

public class CompareDecimalLessThanAttribute : ValidationAttribute {
  public CompareDecimalLessThanAttribute(string propToCompare) {
    _propToCompare = propToCompare;
  }

  private readonly string _propToCompare;

  protected override ValidationResult IsValid(object value, ValidationContext vc) {
    if (value != null) {
      // Get value entered
      decimal currentValue = (decimal)value;
      // Get PropertyInfo for comparison property
      PropertyInfo pinfo = vc.ObjectType.GetProperty(_propToCompare);
      // Ensure the comparison property
      // value is not null
      if (pinfo.GetValue(vc.ObjectInstance) != null) {
        // Get value for comparison property
        decimal comparisonValue = (decimal)pinfo.GetValue(vc.ObjectInstance);
        // Perform the comparison
        if (currentValue > comparisonValue) {
          return new ValidationResult(ErrorMessage,
            new[] { vc.MemberName });
        }
      }
    }

    return ValidationResult.Success;
  }
}
