﻿#nullable disable

using System.ComponentModel.DataAnnotations;

namespace Samples;

public class DateMaximumAttribute : ValidationAttribute {
  public DateMaximumAttribute(string maxDate) {
    _maxDate = Convert.ToDateTime(maxDate);
  }

  private readonly DateTime _maxDate;

  protected override ValidationResult IsValid(object value, ValidationContext vc) {
    if (value != null) {
      // Get the value entered
      DateTime dateEntered = (DateTime)value;

      // Get display name for validation message
      string displayName = vc.DisplayName;

      // See if the date entered is greater than
      // or equal to the maximum date set
      if (dateEntered >= _maxDate) {
        // Check if ErrorMessage is filled in
        if (string.IsNullOrEmpty(ErrorMessage)) {
          ErrorMessage = $"{displayName} must be less than or equal to '{_maxDate:MM/dd/yyyy}'.";
        }

        return new ValidationResult(ErrorMessage,
          new[] { vc.MemberName });
      }
    }

    return ValidationResult.Success;
  }
}
